/*
 * This program calculates a worker's raised salary using progressive raise.
 * Raised salary of a worker is calculated according to the following formula:
 *			salary = salary + salary * (raise percentage)
 * 
 * Raises are defined according to current salary of the worker. For instance,
 * if worker's current salary is less than or equal to 1000 ytl, then its 
 * salary is increased %15. Raises are defined below:
 *
 *    0 < salary <= 1000	: 15%
 * 1000 < salary <= 2000	: 10%
 * 2000 < salary <= 3000	:  5%
 * 3000 < salary			:  2.5% 
 *
 * This program shows the difference between using a nested if structure
 * and using a series of independent if structures.
 *
 * To see the difference try salary values that are close to upper limit of
 * if statements (e.g. 900, 1900, ...)
 */

#include <iostream>

using namespace std;

//calculate raised salary using nested if structure
void calculateRaise1(double salary)
{
	if (salary <= 1000)
	{
		salary = salary + salary * (15.0 / 100);
	}
	else if (salary > 1000 && salary <= 2000)
	{
		salary = salary + salary * (10.0 / 100);
	}
	else if (salary > 2000 && salary <= 3000)
	{
		salary = salary + salary * (5.0 / 100);
	}
	else if (salary > 3000)
	{
		salary = salary + salary * (2.5 / 100); 
	}

	cout << "Your raised salary is " << salary << endl;
}

//calculate raised salary using a series of independent if structures
void calculateRaise2(double salary)
{
	if (salary <= 1000)
	{
		salary = salary + salary * (15.0 / 100);
	}
	if (salary > 1000 && salary <= 2000)
	{
		salary = salary + salary * (10.0 / 100);
	}
	if (salary > 2000 && salary <= 3000)
	{
		salary = salary + salary * (5.0 / 100);
	}
	if (salary > 3000)
	{
		salary = salary + salary * (2.5 / 100); 
	}

	cout << "Your raised salary is " << salary << endl;
}

//calculate raised salary using bottom to top if statements
void calculateRaise3(double salary)
{
	if (salary <= 1000)
	{
		salary = salary + salary * (15.0 / 100);
	}
	else
	if (salary <= 2000)
	{
		salary = salary + salary * (10.0 / 100);
	}
	else
	if (salary <= 3000)
	{
		salary = salary + salary * (5.0 / 100);
	}
	else
	if (salary > 3000)
	{
		salary = salary + salary * (2.5 / 100); 
	}

	cout << "Your raised salary is " << salary << endl;
}

//calculate raised salary using top to bottom if statements
void calculateRaise4(double salary)
{
	if (salary > 3000)
	{
		salary = salary + salary * (2.5 / 100); 
	}
	else
	if (salary > 2000)
	{
		salary = salary + salary * (5.0 / 100);
	}
	else
	if (salary > 1000)
	{
		salary = salary + salary * (10.0 / 100);
	}
	else
	if (salary > 0)
	{
		salary = salary + salary * (15.0 / 100);
	}

	cout << "Your raised salary is " << salary << endl;
}

int main()
{
	double salary;

    //input user's salary
	cout << "Please enter your salary: ";
	cin >> salary;

	if (salary <= 0)
	{
		cout << "Salary must be positive" << endl;
	}
	else
	{
		cout << endl << "With a nested if structure" << endl;
		calculateRaise1(salary);

		cout << endl << "With a series of independent if structures" << endl;
		calculateRaise2(salary);
	//	calculateRaise3(salary);
	//	calculateRaise4(salary);
		cout << endl;
	}

	return 0;
}